@@ -21,9 +21,8 @@
 #include "mainwindow.h"
 #include "mainwidget.h"
 #include "settings.h"
-
-#include <KConfigGroup>
 #include <KToolBar>
+#include <KConfigGroup>
 #include <QAction>
 #include <KActionCollection>
 #include <KEditToolBar>
@@ -32,8 +31,8 @@
 #include <KLocalizedString>
 #include <KSharedConfig>
 #include <KMessageBox>
-#include <KToggleAction>
 #include <QMenuBar>
+#include <QPointer>
 
 MainWindow::MainWindow()
     : KXmlGuiWindow(nullptr)
@@ -97,9 +96,10 @@ void MainWindow::configureToolbars()
     KConfigGroup grp = KSharedConfig::openConfig()->group("MainWindow");
     saveMainWindowSettings(grp);
 
-    KEditToolBar dlg(factory());
-    connect(&dlg, &KEditToolBar::newToolBarConfig, this, &MainWindow::newToolbarConfig);
-    dlg.exec();
+    QPointer<KEditToolBar> dlg = new KEditToolBar(factory());
+    connect(dlg.data(), &KEditToolBar::newToolBarConfig, this, &MainWindow::newToolbarConfig);
+    dlg->exec();
+    delete dlg;
 }
 
 void MainWindow::newToolbarConfig()
